package com.seeyon.ctp.portal.portlet;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.seeyon.apps.govdoc.manager.GovdocListManager;
import com.seeyon.ctp.common.AppContext;
import com.seeyon.ctp.common.authenticate.domain.User;
import com.seeyon.ctp.common.authenticate.domain.UserHelper;
import com.seeyon.ctp.common.exceptions.BusinessException;
import com.seeyon.ctp.common.flag.SysFlag;
import com.seeyon.ctp.common.i18n.ResourceUtil;
import com.seeyon.ctp.common.supervise.manager.SuperviseManager;
import com.seeyon.ctp.organization.OrgConstants;
import com.seeyon.ctp.organization.bo.V3xOrgRole;
import com.seeyon.ctp.organization.manager.OrgManager;
import com.seeyon.ctp.portal.portlet.PortletConstants.ImageType;
import com.seeyon.ctp.portal.portlet.PortletConstants.PortletCategory;
import com.seeyon.ctp.portal.portlet.PortletConstants.PortletSize;
import com.seeyon.ctp.portal.portlet.PortletConstants.UrlType;
import com.seeyon.ctp.privilege.bo.PrivMenuBO;
import com.seeyon.ctp.privilege.bo.PrivTreeNodeBO;
import com.seeyon.ctp.privilege.dao.PrivilegeCache;
import com.seeyon.ctp.privilege.enums.PrivMenuTypeEnums;
import com.seeyon.ctp.resourceEngine.bo.ResourceConfigBO;
import com.seeyon.ctp.resourceEngine.manager.PrivilegeConfigManager;
import com.seeyon.ctp.resourceEngine.manager.ResourceDataManager;
import com.seeyon.ctp.resourceEngine.util.MenuAsAppUtils;
import com.seeyon.ctp.util.FlipInfo;
import com.seeyon.ctp.util.StringUtil;
import com.seeyon.ctp.util.Strings;

public class EdocPortlet implements BasePortlet {
	
	private static final Log LOGGER = LogFactory.getLog(EdocPortlet.class);

	private SuperviseManager superviseManager;
	private GovdocListManager govdocListManager;
	private PrivilegeCache privilegeCache;
	private OrgManager orgManager;
	
	public OrgManager getOrgManager() {
		return orgManager;
	}

	public void setOrgManager(OrgManager orgManager) {
		this.orgManager = orgManager;
	}

	@Override
	public String getId() {
		return "edocPortlet";
	}

	@Override
	public List<ImagePortletLayout> getData() {
		User user = AppContext.getCurrentUser();
		Set<String> menuResStr = new HashSet<String>();
		Boolean isAdmin = user.isAdmin();
		if(isAdmin) {
			try {
				List<V3xOrgRole> roles = orgManager.getAllRoles(user.getAccountId());
				if (null != roles) {
					Set<Long> roleIds = new HashSet<Long>();
					for (V3xOrgRole role : roles) {
						if (role != null) {
							roleIds.add(role.getId());
						}
					}
					HashSet<PrivMenuBO> menuList = privilegeCache.getMenuByRoleFonEntity(roleIds.toArray(new Long[roleIds.size()]));
					for (Iterator<PrivMenuBO> iterator = menuList.iterator(); iterator.hasNext();) {
						PrivMenuBO  menu=iterator.next();
						if(menu!=null&&"edoc".equals(menu.getResourceModuleid())) {
							menuResStr.add(menu.getResourceCode());
						}
					}
				}
			}catch(Exception e) {
				LOGGER.error("", e);
			}
		}
		List<ImagePortletLayout> layouts = new ArrayList<ImagePortletLayout>();
		//发文管理
		if(!isAdmin||menuResStr.contains("F20_govDocSendManage")) {
			layouts.add(this.getSendEdocManagerPortlet());
		}
		//收文管理
		if(!isAdmin||menuResStr.contains("F20_receiveManage")) {
			layouts.add(this.getRecManagerPortlet());
		}
		if(!(Boolean)SysFlag.sys_isG6S.getFlag()){
			//签报管理
			if(!isAdmin||menuResStr.contains("F20_signReport")) {
				layouts.add(this.getSignReportPortlet());
			}
			//签报拟文
			if(!isAdmin||menuResStr.contains("F20_newSign")) {
				layouts.add(this.getSignReportNewPortlet());
			}
			//客开 项目名称： 作者：fzc 修改日期：2018-3-28 [修改功能：]start
            //公文查询
			if(!isAdmin||menuResStr.contains("F20_search")) {
				layouts.add(this.getEdocQueryPortlet());
			}
            //公文统计
			if(!isAdmin||menuResStr.contains("F20_stat")) {
				layouts.add(this.getEdocStatisticsPortlet());
			}
			//客开 项目名称： 作者：fzc 修改日期：2018-3-28 [修改功能：]end

            //GOVB-3213
            //【升级】应用磁贴，公文管理下显示了两个快速发文
            //layouts.add(this.getEdocNewQuickSendPortletPortlet());
		}
		//公文交换 old
		//layouts.add(this.getEdocExchangePortlet());
		//公文督办
		if(!isAdmin||menuResStr.contains("F20_supervise")) {
			layouts.add(this.getEdocSupervisePortlet());
		}
		//收文登记
		if(!isAdmin||menuResStr.contains("F20_newDengji")) {
			layouts.add(this.getEdocRecRegisterPortlet());
		}
		//公文
		layouts.add(this.getEdocPortlet());
		//发文拟文
		if(!isAdmin||menuResStr.contains("F20_newSend")) {
			layouts.add(this.getEdocSendNewPortletPortlet());
		}
		//待办公文
		if(!isAdmin||menuResStr.contains("F20_govdocPending")) {
			layouts.add(this.getPendingEdocPortlet());
		}
		//快速发文
		if(!isAdmin||menuResStr.contains("F20_fawenNewQuickSend")) {
			layouts.add(this.getQuickSendPortlet());
		}
		//已办公文
		if(!isAdmin||menuResStr.contains("F20_govDocDone")) {
			layouts.add(this.getDoneGovdocPortlet());
		}
		//已发公文
		if(!isAdmin||menuResStr.contains("F20_gocDovSend")) {
			layouts.add(this.getSentGovdocPortlet());
		}
		//待发公文
		if(!isAdmin||menuResStr.contains("F20_govDocWaitSend")) {
			layouts.add(this.getWaitSendGovdocPortlet());
		}
		//公文交换
		if(!isAdmin||menuResStr.contains("F20_govdocExchange")) {
			layouts.add(this.getExchangeGovdocPortlet());
		}
		//代领导批示
		if(!isAdmin||menuResStr.contains("F20_leaderPishi")) {
			layouts.add(this.getLeaderPishiPortlet());
		}
		
		layouts.addAll(getGovdocMenuPortlets());
		layouts.addAll(getGovdocFirstLevelMenuPortlets());
		return layouts;
	}
	
	@Override
	public ImagePortletLayout getPortlet(String portletId) {
		List<ImagePortletLayout> layouts = this.getData();
		if(CollectionUtils.isNotEmpty(layouts)){
			for(ImagePortletLayout layout : layouts){
				if(portletId.equals(layout.getPortletId())){
					return layout;
				}
			}
		}
		return null;
	}


	/*@Override
	public int getDataCount(String portletId) {
		try {
			User user = AppContext.getCurrentUser();
			
			//发文、收文、签报待办数
	        if("sendManagerPortlet".equals(portletId) || "recManagerPortlet".equals(portletId) ||"signReportPortlet".equals(portletId)){
	        	int pendingCount=0;
	        	 String listType = "listPendingAll" ;
	 		    int type = EdocNavigationEnum.EdocV5ListTypeEnum.getEnumByKey(listType).getType();
	 		    Map<String, Object> condition = new HashMap<String, Object>();
	 		    int edocType=0;
	 		    if("sendManagerPortlet".equals(portletId)){
	 		    	edocType=0;
	 		    }else if("recManagerPortlet".equals(portletId)){
	 		    	edocType=1;
	 		    }else if("signReportPortlet".equals(portletId)){
	 		    	edocType=2;
	 		    }
	 		    condition.put("edocType", edocType);
	 		    condition.put("state", StateEnum.col_pending.key());
	 	        condition.put("user", user);
	 	        condition.put("listType","listPending");
	 	        condition.put("userId", user.getId()); 
	 			condition.put("accountId", user.getLoginAccount());//不需要进行分页查询，
	 			pendingCount  = edocListManager.findEdocPendingCount(type, condition);
	 			return  pendingCount;
	        }else if("edocExchangePortlet".equals(portletId)){ //待交换数据（待发送和待签收）的和
	        	int count1 = 0;
	        	int count2 = 0;
	        	Map<String, Object> condition = new HashMap<String, Object>();
	        	String listType="listExchangeToSend";
	    		condition.put("listType", "listExchangeToSend");
	    		condition.put("modelType", "toSend");
	    		condition.put("user", user);
	    		int type = EdocNavigationEnum.EdocV5ListTypeEnum.getTypeName(listType);
	    		count1 =  edocExchangeManager.findEdocExchangeRecordCount(type, condition);
	        	listType="listExchangeToRecieve";
	    		condition.put("listType", "listExchangeToRecieve");
	    		condition.put("modelType", "toSend");
	    		condition.put("user", user);
	    		type = EdocNavigationEnum.EdocV5ListTypeEnum.getTypeName(listType);
	    		count2 =  edocExchangeManager.findEdocExchangeRecordCount(type, condition);
	        	return count1+count2;
	        	
	        }else if("edocSupervisePortlet".equals(portletId)){ //公文督办
	        	Map<String, String> query = new HashMap<String, String>();
	        	query.put("app", "4");
	        	int dateCount=0;
	        	
    	        FlipInfo a = superviseManager.getSuperviseList4App(new FlipInfo(), query);
    	        if(a!=null){
    	        	dateCount = a.getTotal();
    	        }
    	        
	        	return dateCount;
	        }
		   
		} catch (BusinessException e) {
			LOGGER.error("首页工作桌面公文查询待办数异常",e);
			return 0;
		}
		
		return -1;
		

	}*/

	/**
	 * 新公文数量统计
	 */
	public int getDataCount(String portletId) {
		try {
			Map<String, String> condition = new HashMap<String, String>();
			condition.put("onlyCount", "true");
			// 发文、收文、签报待办数
			if ("pendingEdocPortlet".equals(portletId) || "edocPortlet".equals(portletId) || "sendManagerPortlet".equals(portletId) || "recManagerPortlet".equals(portletId) || "signReportPortlet".equals(portletId)) {
				//2020-03-27 chenhao 将listPendingAll 修改为 listPending
                // GOVB-3291
                //【升级】580sp1升级到80，应用磁贴上收文管理显示27，点击后发现里面只有25
			    String listType = "listPending";
				String govdocType = null;
				if ("sendManagerPortlet".equals(portletId)) {
					govdocType = "1";
				} else if ("recManagerPortlet".equals(portletId)) {
					govdocType = "2,4";
				} else if ("signReportPortlet".equals(portletId)) {
					govdocType = "3";
				} else if ("pendingEdocPortlet".equals(portletId)) {
					govdocType = "1,2,3,4";
				}
				condition.put("govdocType", govdocType);
				condition.put("listType", listType);
				return govdocListManager.getPendingTotalCount(condition);
			} else if ("edocExchangePortlet".equals(portletId)) { // 待交换数据（待发送和待签收）的和
				condition.put("listType", "listExchangeSendPending");
				return govdocListManager.getPendingTotalCount(condition);
			} else if ("edocSupervisePortlet".equals(portletId)) { // 公文督办
				Map<String, String> query = new HashMap<String, String>();
				query.put("app", "4");
				int dateCount = 0;

				FlipInfo a = superviseManager.getSuperviseList4App(new FlipInfo(), query);
				if (a != null) {
					dateCount = a.getTotal();
				}

				return dateCount;
			}else{
				String reg = "[-]{0,1}[0-9]*";
				if(portletId!=null && portletId.matches(reg)){
					ResourceDataManager rdm = (ResourceDataManager)AppContext.getBean("resourceDataManager");
					String r = rdm.getTotalByMenuId4ShortCut(portletId);
					if(Strings.isBlank(r)){
						return 0;
					}else{
						return Integer.parseInt(r);
					}
				}
			}

		} catch (BusinessException e) {
			LOGGER.error("首页工作桌面公文查询待办数异常", e);
			return 0;
		}

		return -1;

	}
    @Override
    public boolean isAllowDataUsed(String portletId) {
    	//由于G6是没有权限判断的，和杨圆沟通后把权限注释
        //if ("edocPortlet".equals(portletId)) {
        //    return AppContext.hasResourceCode("F07_sendManager") || AppContext.hasResourceCode("F07_recManager") || AppContext.hasResourceCode("F07_signReport");
        //}
    	ImagePortletLayout layout = getPortlet(portletId);
    	if (layout != null) {
            String pluginId = layout.getPluginId();
            String resourceCodes = layout.getResourceCode();
            boolean hasResourceCode = false;
            if(Strings.isNotBlank(resourceCodes)){
            	for (String resourceCode : StringUtil.split(resourceCodes, ",")) {
					if(AppContext.hasResourceCode(resourceCode)){
						hasResourceCode = true;
						break;
					}
				}
            }
            return (Strings.isBlank(pluginId) || AppContext.hasPlugin(pluginId)) && hasResourceCode;
        } else {
            return false;
        }
    }

	@Override
	public boolean isAllowUsed() {
		return true;
	}

	//客开 项目名称： 作者：fzc 修改日期：2018-3-28 [修改功能：]start
    /**
     *公文查询
     * @return
     */
	private ImagePortletLayout getEdocQueryPortlet() {
	    ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_search");
        layout.setPluginId("edoc");
        layout.setCategory(PortletCategory.edoc.name());
        layout.setDisplayName("system.menuname.DocSearch");
        layout.setOrder(10);
        layout.setNeedNumber(0);
        layout.setPortletId("edocSearchPortlet");
        layout.setPortletName(ResourceUtil.getString("menu.edoc.query.label"));//公文查询
		layout.setPortletUrl("/govdoc/govdoc.do?method=queryIndex&_resourceCode=F20_search");
        layout.setPortletUrlType(UrlType.open.name());
        layout.setSize(PortletSize.middle.ordinal());
        List<ImageLayout> ims = new ArrayList<ImageLayout>();
        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.DocSearch");
        image1.setSummary("");
        image1.setImageUrl("d_docsearch.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
	}

    /**
     * 公文统计
     * @return
     */
	private ImagePortletLayout getEdocStatisticsPortlet() {
	    ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_stat");
        layout.setPluginId("edoc");
        layout.setCategory(PortletCategory.edoc.name());
        layout.setDisplayName("system.menuname.DocStatistics");
        layout.setOrder(11);
        layout.setNeedNumber(0);
        layout.setPortletId("edocStatisticsPortlet");
        layout.setPortletName(ResourceUtil.getString("menu.statisticsManager.label"));//公文统计
		layout.setPortletUrl("/govdoc/govdoc.do?method=statIndex&listType=listOldStat&_resourceCode=F20_stat");
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setSize(PortletSize.middle.ordinal());
        List<ImageLayout> ims = new ArrayList<ImageLayout>();

        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.DocStatistics");
        image1.setSummary("");
        image1.setImageUrl("d_docstatistics.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
	}
	//客开 项目名称： 作者：fzc 修改日期：2018-3-28 [修改功能：]end

	/**
	 * 发文管理
	 * @return
	 */
	private ImagePortletLayout getSendEdocManagerPortlet() {
	    ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_govDocSendManage");
        layout.setPluginId("edoc");
        layout.setCategory(PortletCategory.edoc.name());
        layout.setDisplayName("system.menuname.DocDispatch");
        layout.setOrder(7);
        layout.setPortletId("sendManagerPortlet");
        layout.setPortletName(ResourceUtil.getString("menu.sendManager.label"));//发文管理
        //layout.setPortletUrl("/edocController.do?method=entryManager&entry=sendManager");
		layout.setPortletUrl("/govdoc/govdoc.do?method=index&govdocType=1&_resourceCode=F20_govDocSendManage");
        //移动端发文管理磁贴 chenyq 20190305
        layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocList.html?listType=send");
        layout.setSpaceTypes("personal,personal_custom,leader,outer,custom,department,corporation,public_custom,group,public_custom_group,cooperation_work,objective_manage,edoc_manage,meeting_manage,performance_analysis,form_application,related_project_space,mobile_application,m3mobile,weixinmobile");
        //移动端发文管理磁贴 chenyq 20190305
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setSize(PortletSize.middle.ordinal());
        layout.setNeedNumber(1);
        List<ImageLayout> ims = new ArrayList<ImageLayout>();

        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.DocDispatch");
        image1.setSummary("");
        image1.setImageUrl("d_docdispatch.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
	}
	/**
	 * 快速发文
	 * @return
	 */
	private ImagePortletLayout getEdocNewQuickSendPortletPortlet() {
		ImagePortletLayout layout = new ImagePortletLayout();
		layout.setPluginId("edoc");
		layout.setCategory(PortletCategory.edoc.name());
		layout.setResourceCode("F20_fawenNewQuickSend");
		layout.setDisplayName("edoc.sendQuick_0.label");
		layout.setPortletUrl("/govdoc/govdoc.do?method=newGovdoc&sub_app=1&isQuickSend=true&_resourceCode=F20_fawenNewQuickSend");
		layout.setOrder(8);
		layout.setPortletId("edocNewQuickSendPortlet");
		layout.setPortletName(ResourceUtil.getString("edoc.sendQuick_0.label"));//快速发文
		layout.setPortletUrlType(UrlType.open.name());
		layout.setSize(PortletSize.middle.ordinal());
		List<ImageLayout> ims = new ArrayList<ImageLayout>();
		ImageLayout image1 = new ImageLayout();
		image1.setImageTitle("edoc.sendQuick_0.label");
		image1.setSummary("");
		image1.setImageUrl("d_edocfawen.png");
		ims.add(image1);
		layout.setImageLayouts(ims);
		return layout;
	}
	
	/**
	 * 发文拟文
	 * @return
	 */
	private ImagePortletLayout getEdocSendNewPortletPortlet() {
		ImagePortletLayout layout = new ImagePortletLayout();
		layout.setPluginId("edoc");
		layout.setCategory(PortletCategory.edoc.name());
		if((Boolean)SysFlag.sys_isG6S.getFlag()){
			layout.setResourceCode("F20_fawenNewQuickSend");
			layout.setDisplayName("system.menuname.quickfawen");
			layout.setPortletUrl("/govdoc/govdoc.do?method=newGovdoc&sub_app=1&isQuickSend=true&_resourceCode=F20_fawenNewQuickSend");
		}else{
			layout.setResourceCode("F20_newSend");
			layout.setDisplayName("system.menuname.edocfawen");
			layout.setPortletUrl("/govdoc/govdoc.do?method=newGovdoc&sub_app=1&_resourceCode=F20_newSend");
		}
		layout.setOrder(0);
        layout.setNeedNumber(0);
		layout.setPortletId("edocSendNewPortlet");
		layout.setPortletName(ResourceUtil.getString("system.menuname.edocfawen"));//发文管理
		layout.setPortletUrlType(UrlType.open.name());
		layout.setSize(PortletSize.middle.ordinal());
		List<ImageLayout> ims = new ArrayList<ImageLayout>();
		ImageLayout image1 = new ImageLayout();
		image1.setImageTitle("system.menuname.edocfawen");
		image1.setSummary("");
		image1.setImageUrl("d_edocfawen.png");
		ims.add(image1);
		layout.setImageLayouts(ims);
		return layout;
	}
	/**
	 * 收文管理
	 * @return
	 */
	private ImagePortletLayout getRecManagerPortlet() {
	    ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_receiveManage");
        layout.setPluginId("edoc");
        layout.setCategory(PortletCategory.edoc.name());
        layout.setDisplayName("system.menuname.DocReceiving");
        layout.setOrder(8);
        layout.setPortletId("recManagerPortlet");
        layout.setPortletName(ResourceUtil.getString("menu.receiveManager.label"));//收文管理
        //layout.setPortletUrl("/edocController.do?method=entryManager&entry=recManager");
		layout.setPortletUrl("/govdoc/govdoc.do?method=index&govdocType=2,4&_resourceCode=F20_receiveManage");
        //移动端收文管理磁贴 chenyq 20190305
        layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocList.html?listType=receive");
        layout.setSpaceTypes("personal,personal_custom,leader,outer,custom,department,corporation,public_custom,group,public_custom_group,cooperation_work,objective_manage,edoc_manage,meeting_manage,performance_analysis,form_application,related_project_space,mobile_application,m3mobile,weixinmobile");
        //移动端收文管理磁贴 chenyq 20190305
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setSize(PortletSize.middle.ordinal());
        layout.setNeedNumber(1);
        List<ImageLayout> ims = new ArrayList<ImageLayout>();

        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.DocReceiving");
        image1.setSummary("");
        image1.setImageUrl("d_docreceiving.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
	}
	/**
	 * 签报拟文
	 * @return
	 */
	private ImagePortletLayout getSignReportNewPortlet() {
	    ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_newSign");
        layout.setPluginId("edoc");
        layout.setCategory(PortletCategory.edoc.name());
        layout.setDisplayName("system.menuname.SignReportNew");
        layout.setOrder(1);
        layout.setNeedNumber(0);
        layout.setPortletId("signReportNewPortlet");
        layout.setPortletName(ResourceUtil.getString("system.menuname.SignReportNew"));//签报拟文
        layout.setPortletUrl("/govdoc/govdoc.do?method=newGovdoc&sub_app=3&_resourceCode=F20_newSign");
        layout.setPortletUrlType(UrlType.open.name());
        layout.setSize(PortletSize.middle.ordinal());
        List<ImageLayout> ims = new ArrayList<ImageLayout>();
        
        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.SignReportNew");
        image1.setSummary("");
        image1.setImageUrl("d_edocqianbao.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
	}
	/**
	 * 签报管理
	 * @return
	 */
	private ImagePortletLayout getSignReportPortlet() {
	    ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_signReport");
        layout.setPluginId("edoc");
        layout.setCategory(PortletCategory.edoc.name());
        layout.setDisplayName("system.menuname.SignReceipt");
        layout.setOrder(8);
        layout.setPortletId("signReportPortlet");
        layout.setPortletName(ResourceUtil.getString("menu.signManager.label"));//签报管理
        //layout.setPortletUrl("/edocController.do?method=entryManager&entry=signReport");
        //客开 项目名称： 作者：fzc 修改日期：2018-3-22 [修改功能：首页磁铁]start
        //layout.setPortletUrl("/govDoc/govDocController.do?method=govDocSend&isSignReport=true&_resourceCode=F20_signReport");
        layout.setPortletUrl("/govdoc/govdoc.do?method=index&govdocType=3&_resourceCode=F20_signReport");
		//客开 项目名称： 作者：fzc 修改日期：2018-3-22 [修改功能：首页磁铁]end
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setSize(PortletSize.middle.ordinal());
        //移动端签报管理磁贴 chenyq 20190305
        layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocList.html?listType=report");
        layout.setSpaceTypes("personal,personal_custom,leader,outer,custom,department,corporation,public_custom,group,public_custom_group,cooperation_work,objective_manage,edoc_manage,meeting_manage,performance_analysis,form_application,related_project_space,mobile_application,m3mobile,weixinmobile");
        //移动端签报管理磁贴 chenyq 20190305
        layout.setNeedNumber(1);
        List<ImageLayout> ims = new ArrayList<ImageLayout>();

        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.SignReceipt");
        image1.setSummary("");
        image1.setImageUrl("d_signreceipt.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
	}
	
	/**
	 * 公文交换 TODO 暂时保存A8
	 * @return
	 */
	private ImagePortletLayout getEdocExchangePortlet() {
	    ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F07_edocExchange");
        layout.setPluginId("edoc");
        layout.setCategory(PortletCategory.edoc.name());
        layout.setDisplayName("system.menuname.DocExchage");
        layout.setOrder(4);
        layout.setPortletId("edocExchangePortlet");
        layout.setPortletName(ResourceUtil.getString("menu.exchangeManager.label"));//公文交换
        layout.setPortletUrl("/exchangeEdoc.do?method=listMainEntry");
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setSize(PortletSize.middle.ordinal());
        List<ImageLayout> ims = new ArrayList<ImageLayout>();

        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.DocExchage");
        image1.setSummary("");
        image1.setImageUrl("d_docexchage.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
	}
	
	/**
	 * 公文督办
	 * @return
	 */
	private ImagePortletLayout getEdocSupervisePortlet() {
	    ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_supervise");
        layout.setPluginId("edoc");
        layout.setCategory(PortletCategory.edoc.name());
        layout.setDisplayName("system.menuname.DocSupervision");
        layout.setOrder(12);
        layout.setNeedNumber(0);
        layout.setPortletId("edocSupervisePortlet");
        layout.setPortletName(ResourceUtil.getString("menu.superviseManager.label"));//公文督办
        //layout.setPortletUrl("/supervise/supervise.do?method=listSupervise&app=4");
		layout.setPortletUrl("/supervise/supervise.do?method=listSupervise&app=4&_resourceCode=F20_supervise");
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setSize(PortletSize.middle.ordinal());
        List<ImageLayout> ims = new ArrayList<ImageLayout>();

        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.DocSupervision");
        image1.setSummary("");
        image1.setImageUrl("d_docsupervision.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
	}
	
	/**
	 * 收文登记
	 * @return
	 */
	private ImagePortletLayout getEdocRecRegisterPortlet() {
		ImagePortletLayout layout = new ImagePortletLayout();
//7.1菜单变动F07_recRegister没了		if(GovdocHelper.isG6Version()){
//			layout.setResourceCode("F20_newDengji");
//		}else{
//			layout.setResourceCode("F07_recRegister");
//		}
		layout.setResourceCode("F20_newDengji");
        layout.setPluginId("edoc");
        layout.setCategory(PortletCategory.edoc.name());
        layout.setDisplayName("system.menuname.edocdengji");
        layout.setOrder(2);
        layout.setNeedNumber(0);
        layout.setPortletId("edocRecRegisterPortlet");
        layout.setPortletName(ResourceUtil.getString("menu.edocRecNew.label"));//收文登记
        //A8的url
        //String url = "/edocController.do?method=entryManager&entry=recManager&listType=newEdoc&edocType=1&listType=listV5Register";
        //g6的url
        //if(EdocHelper.isG6Version()){
        //	url = "/edocController.do?method=entryManager&entry=recManager&listType=newEdocRegister&comm=create&edocType=1&registerType=2&sendUnitId=-1&registerId=-1&listType=registerPending&recListType=registerPending";
        //}
        //if(EdocSwitchHelper.isOpenRegister()==false){
        //	url="/edocController.do?method=entryManager&entry=recManager&listType=newEdoc&edocType=1";
        //}
		String url="/govdoc/govdoc.do?method=newGovdoc&sub_app=2&_resourceCode=F20_newDengji";//更换为新链接
        layout.setPortletUrl(url);
        layout.setPortletUrlType(UrlType.open.name());
        layout.setSize(PortletSize.middle.ordinal());
        List<ImageLayout> ims = new ArrayList<ImageLayout>();

        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.edocdengji");
        image1.setSummary("");
        image1.setImageUrl("d_edocdengji.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
	}
	
	/**
     * 公文
     * @return
     */
    private ImagePortletLayout getEdocPortlet() {
        ImagePortletLayout layout = new ImagePortletLayout();
        //2020-03-23 chenhao M3端：公文管理 权限限制为：待办公文、已办公文、发文管理、收文管理、签报管理
        layout.setResourceCode("F20_govdocPending,F20_govDocDone,F20_govDocSendManage,F20_receiveManage,F20_signReport");
        layout.setPluginId("edoc");
        layout.setCategory("common,edoc");
        layout.setOrder(80);
        layout.setPortletId("edocPortlet");
        layout.setPortletName(ResourceUtil.getString("taskmanage.govdoc.label"));
        layout.setDisplayName("pending.edoc.label");
        layout.setNeedNumber(1);
        layout.setPortletUrl("");
        layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocList.html");
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setSize(PortletSize.middle.ordinal());
        layout.setSpaceTypes("m3mobile,weixinmobile,mobile_application");
        List<ImageLayout> ims = new ArrayList<ImageLayout>();

        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("pending.edoc.label");
        image1.setSummary("");
        image1.setImageUrl("d_officthemespace.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
    }
    
    /**
     * 待办公文
     * @return
     */
    private ImagePortletLayout getPendingEdocPortlet() {
        ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_govdocPending");
        layout.setPluginId("edoc");
        layout.setCategory("edoc");
        layout.setOrder(3);
        layout.setPortletId("pendingEdocPortlet");
        layout.setPortletUrl("/govdoc/govdoc.do?method=index&listType=listPendingAllRoot&_resourceCode=F20_govdocPending");
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setPortletName(ResourceUtil.getString("taskmanage.govdoc_todo.label"));
        layout.setDisplayName("edoc.section.pending.label");
        layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocList.html#allPending_");
        layout.setSize(PortletSize.middle.ordinal());
        layout.setSpaceTypes("m3mobile,weixinmobile,personal,mobile_application");
        layout.setNeedNumber(1);
        List<ImageLayout> ims = new ArrayList<ImageLayout>();
        
        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("edoc.section.pending.label");
        image1.setSummary("");
        image1.setImageUrl("d_officthemespace.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
    }
    
    private ImagePortletLayout getQuickSendPortlet() {
        ImagePortletLayout layout = new ImagePortletLayout();
		layout.setResourceCode("F20_fawenNewQuickSend");
		layout.setDisplayName("system.menuname.edocQuickSend");
		layout.setPortletUrl("/govdoc/govdoc.do?method=newGovdoc&sub_app=1&isQuickSend=true&_resourceCode=F20_fawenNewQuickSend");
        layout.setPluginId("edoc");
        layout.setCategory("edoc");
        layout.setOrder(9);
        layout.setPortletId("quickSendPortlet");
        layout.setPortletUrlType(UrlType.open.name());
        layout.setPortletName(ResourceUtil.getString("system.menuname.edocQuickSend"));
        layout.setSize(PortletSize.middle.ordinal());
        layout.setNeedNumber(0);
        List<ImageLayout> ims = new ArrayList<ImageLayout>();
        
        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.edocQuickSend");
        image1.setSummary("");
        image1.setImageUrl("d_edocfawen.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
		return layout;
    }
    
    private ImagePortletLayout getDoneGovdocPortlet() {
        ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_govDocDone");
        layout.setPluginId("edoc");
        layout.setCategory("edoc");
        layout.setOrder(4);
        layout.setPortletId("doneGovdocPortlet");
        layout.setPortletUrl("/govdoc/govdoc.do?method=index&listType=listDoneAllRoot&_resourceCode=F20_govDocDone");
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setPortletName(ResourceUtil.getString("edoc.section.done.label"));
        layout.setDisplayName("edoc.section.done.label");
        layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocList.html?listType=allDone");
        layout.setSize(PortletSize.middle.ordinal());
        layout.setSpaceTypes("personal,personal_custom,leader,outer,custom,department,corporation,public_custom,group,public_custom_group,cooperation_work,objective_manage,edoc_manage,meeting_manage,performance_analysis,form_application,related_project_space,mobile_application,m3mobile,weixinmobile");
        layout.setNeedNumber(0);
        List<ImageLayout> ims = new ArrayList<ImageLayout>();
        
        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("edoc.section.done.label");
        image1.setSummary("");
        image1.setImageUrl("doc-doneevent.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
    }
    
    private ImagePortletLayout getSentGovdocPortlet() {
        ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_gocDovSend");
        layout.setPluginId("edoc");
        layout.setCategory("edoc");
        layout.setOrder(5);
        layout.setPortletId("sentGovdocPortlet");
        layout.setPortletUrl("/govdoc/govdoc.do?method=index&listType=listSentAllRoot&_resourceCode=F20_gocDovSend");
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setPortletName(ResourceUtil.getString("edoc.section.sent.label"));
        layout.setDisplayName("edoc.section.sent.label");
        layout.setSize(PortletSize.middle.ordinal());
        layout.setNeedNumber(0);
        List<ImageLayout> ims = new ArrayList<ImageLayout>();
        
        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("edoc.section.sent.label");
        image1.setSummary("");
        image1.setImageUrl("doc-sentevent.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
    }
    private ImagePortletLayout getWaitSendGovdocPortlet() {
    	ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_govDocWaitSend");
        layout.setPluginId("edoc");
        layout.setCategory("edoc");
        layout.setOrder(6);
        layout.setPortletId("waitSendGovdocPortlet");
        layout.setPortletUrl("/govdoc/govdoc.do?method=index&listType=listSentAllRoot&_resourceCode=F20_gocDovSend");
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setPortletName(ResourceUtil.getString("edoc.section.sent.label"));
        layout.setDisplayName("edoc.section.waitsent.label");
        //layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocList.html#allWaitSend_");
        layout.setSize(PortletSize.middle.ordinal());
        layout.setNeedNumber(0);
        List<ImageLayout> ims = new ArrayList<ImageLayout>();
        
        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("edoc.section.waitsent.label");
        image1.setSummary("");
        image1.setImageUrl("doc-unsentevent.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
    }
    private ImagePortletLayout getExchangeGovdocPortlet() {
    	ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_govdocExchange");
        layout.setPluginId("edoc");
        layout.setCategory("edoc");
        layout.setOrder(9);
        layout.setPortletId("exchangeGovdocPortlet");
        layout.setPortletUrl("/govdoc/exchange.do?method=exchangeIndex&_resourceCode=F20_govdocExchange");
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setPortletName(ResourceUtil.getString("system.menuname.DocExchage"));
        layout.setDisplayName("system.menuname.DocExchage");
        //layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocList.html#allWaitSend_");
        layout.setSize(PortletSize.middle.ordinal());
        layout.setNeedNumber(1);
        List<ImageLayout> ims = new ArrayList<ImageLayout>();
        
        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.DocExchage");
        image1.setSummary("");
        image1.setImageUrl("docexchage.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
    }
    private ImagePortletLayout getLeaderPishiPortlet() {
    	ImagePortletLayout layout = new ImagePortletLayout();
        layout.setResourceCode("F20_leaderPishi");
        layout.setPluginId("edoc");
        layout.setCategory("edoc");
        layout.setOrder(13);
        layout.setPortletId("leaderPishiPortlet");
        layout.setPortletUrl("/govdoc/govdoc.do?method=leaderPishiList&_resourceCode=F20_leaderPishi");
        layout.setPortletUrlType(UrlType.workspace.name());
        layout.setPortletName(ResourceUtil.getString("system.menuname.DocConfigLeaderPishi"));
        layout.setDisplayName("system.menuname.DocConfigLeaderPishi");
        //layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocList.html#allWaitSend_");
        layout.setSize(PortletSize.middle.ordinal());
        layout.setNeedNumber(1);
        List<ImageLayout> ims = new ArrayList<ImageLayout>();
        
        ImageLayout image1 = new ImageLayout();
        image1.setImageTitle("system.menuname.DocConfigLeaderPishi");
        image1.setSummary("");
        image1.setImageUrl("docconfig.png");
        ims.add(image1);
        layout.setImageLayouts(ims);
        return layout;
    }
    
    private List<ImagePortletLayout> getGovdocMenuPortlets() {
    	List<ImagePortletLayout> layouts = new ArrayList<ImagePortletLayout>();
    	List<PrivMenuBO> menus = privilegeCache.getAllMenu();
    	int order = 440;
    	PrivilegeConfigManager manager = (PrivilegeConfigManager)AppContext.getBean("privilegeConfigManager");
    	for(PrivMenuBO bo:menus){
    	    //2020-03-24 chenhao 添加 bo.getShortCut()!=null 条件
            //GOVB-3006
            //【升级环境】571SP1升级，应用磁铁添加报错
    		if(bo.getShortCut()!=null&&bo.getShortCut() && bo.getType()!=null && PrivMenuTypeEnums.privConfigMenu.getKey() == bo.getType() && bo.getEnterResource()!=null &&bo.getEnterResource() == 1 && "edoc".equals(bo.getResourceModuleid())){//配置的实体菜单
    			List<ResourceConfigBO> resources = manager.findByParentMenuId(bo.getId(), null);
				if (CollectionUtils.isEmpty(resources)) {
					continue;
				}
    			ImagePortletLayout layout = new ImagePortletLayout();
    	        layout.setResourceCode(bo.getResourceCode());
    	        layout.setPluginId("edoc");
    	        layout.setCategory("edoc");
    	        layout.setOrder(order++);
    	        layout.setPortletId(bo.getId().toString());
    	        layout.setPortletUrl(bo.getResourceNavurl());
    	        layout.setPortletUrlType("newWindow".equals(bo.getTarget())?UrlType.open.name():UrlType.workspace.name());
    	        layout.setPortletName(bo.getName());
                layout.setDisplayName(bo.getName());
                //layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocList.html#allPending_");
                layout.setSize(PortletSize.middle.ordinal());
                layout.setSpaceTypes("personal,personal_custom,leader,outer,custom,department,corporation,public_custom,group,public_custom_group,cooperation_work,objective_manage,edoc_manage,meeting_manage,performance_analysis,form_application,related_project_space");
                layout.setNeedNumber(1);
    	        List<ImageLayout> ims = new ArrayList<ImageLayout>();
    	        
    	        ImageLayout image1 = new ImageLayout();
    	        image1.setImageTitle(bo.getName());
    	        image1.setSummary("");
    	        image1.setImageUrl(bo.getShortCutIcon());
    	        if(bo.getShortCutIcon() != null && bo.getShortCutIcon().indexOf("fileUpload.do") > -1){
    	        	image1.setImageType(ImageType.link);
    	        }
    	        ims.add(image1);
    	        layout.setImageLayouts(ims);
    	        layouts.add(layout);
    		}
    	}
        return layouts;
    }

    /**
     * 添加一级菜单作为磁铁
     * @return
     */
    private List<ImagePortletLayout> getGovdocFirstLevelMenuPortlets() {
        User user=AppContext.getCurrentUser();

        List<ImagePortletLayout> layouts = new ArrayList<ImagePortletLayout>();
        //用户为空，则不进行添加（应用初始化的情况）
        if(user==null){
            return layouts;
        }
        int order = 400;
        List<PrivTreeNodeBO> list= MenuAsAppUtils.findFirstLevelMenu();
        PrivTreeNodeBO privTreeNodeBO ;
        PrivMenuBO bo;
        for (int i = 0; i < list.size(); i++) {
            privTreeNodeBO =  list.get(i);
            bo=privTreeNodeBO.getMenu();
            //管理员判断,管理员只判断是否资源被M3支持
            if (user.isAdmin()){
                if(!MenuAsAppUtils.menuHasM3SupportResource(bo))continue;
            }
            //普通用户判断
            else if (!MenuAsAppUtils.filteredMenuByPowerIsM3Support(MenuAsAppUtils.findHasPowerMenu(bo)))
            {
                continue;
            }
            ImagePortletLayout layout = new ImagePortletLayout();
            layout.setResourceCode(bo.getResourceCode());
            //layout.setResourceCode("");//设置为空resourceCode
            layout.setPluginId("edoc");
            layout.setCategory("edoc");
            layout.setOrder(order++);
            layout.setPortletId(privTreeNodeBO.getIdKey());
            layout.setPortletUrl(bo.getResourceNavurl());
            layout.setPortletUrlType(UrlType.workspace.name());
            layout.setPortletName(privTreeNodeBO.getNameKey());
            layout.setDisplayName(bo.getName());
            //移动端磁贴-空间类型只保留移动端的
            String id = privTreeNodeBO.getIdKey().replaceFirst("menu_","");
            layout.setMobileUrl("/seeyon/m3/apps/v5/edoc/html/edocMenu.html?id="+id+"&appName="+bo.getName());
            layout.setSpaceTypes("mobile_application,m3mobile,weixinmobile");
            //移动端磁贴
            layout.setSize(PortletSize.middle.ordinal());
            layout.setNeedNumber(0);
            List<ImageLayout> ims = new ArrayList<ImageLayout>();

            ImageLayout image1 = new ImageLayout();
            image1.setImageTitle(bo.getName());
            image1.setSummary("");
            image1.setImageUrl(Strings.isEmpty(bo.getShortCutIcon())?"d_officthemespace.png":bo.getShortCutIcon());//默认为公文的
            if (bo.getShortCutIcon() != null && bo.getShortCutIcon().indexOf("fileUpload.do") > -1) {
                image1.setImageType(ImageType.link);
            }
            ims.add(image1);
            layout.setImageLayouts(ims);
            layouts.add(layout);
        }
        return layouts;
    }
    
    public void setSuperviseManager(SuperviseManager superviseManager) {
		this.superviseManager = superviseManager;
	}
	public void setGovdocListManager(GovdocListManager govdocListManager) {
		this.govdocListManager = govdocListManager;
	}

	public PrivilegeCache getPrivilegeCache() {
		return privilegeCache;
	}

	public void setPrivilegeCache(PrivilegeCache privilegeCache) {
		this.privilegeCache = privilegeCache;
	}
	
}
